golgotha.maps.acars = golgotha.maps.acars || {acPositions:[], dcPositions:[], routeData:null, routeWaypoints:null, tempData:null, routeMarkers:[]};
golgotha.maps.acars.generateXMLRequest = function()
{
const xmlreq = new XMLHttpRequest();
xmlreq.timeout = 2500;
xmlreq.open('get', 'acars_map_json.ws?time=' + golgotha.util.getTimestamp(3000), true);
xmlreq.ontimeout = function() { golgotha.util.setHTML('isLoading', ' - TIMEOUT'); return true; };
xmlreq.onreadystatechange = function() {
	if (xmlreq.readyState != 4) return false;
	if (xmlreq.status != 200) {
		golgotha.util.setHTML('isLoading', ' - ERROR ' + xmlreq.status);
		return false;
	}

	// Clean up the map - don't strip out the weather layer
	golgotha.util.setHTML('isLoading', ' - REDRAWING...');
	map.removeMarkers(golgotha.maps.acars.routeData);
	map.removeMarkers(golgotha.maps.acars.routeWaypoints);
	map.removeMarkers(golgotha.maps.acars.acPositions);
	map.removeMarkers(golgotha.maps.acars.dcPositions);
	golgotha.maps.acars.acPositions.length = 0;
	golgotha.maps.acars.dcPositions.length = 0;
	golgotha.util.display('userSelect', false);
	const cbo = document.forms[0].usrID;
	if (cbo != null) {
		selectedPilot = cbo.options[cbo.selectedIndex].value;
		cbo.options.length = 1;
	}

	// Parse the JSON
	const js = JSON.parse(xmlreq.responseText);
	if (js.aircraft.length > 0) golgotha.event.beacon('ACARS', 'Aircraft Positions');
	const allAC = js.aircraft.sort(golgotha.maps.acars.sort);
	allAC.forEach(function(a) {
		var mrk;
		if (a.pal)
			mrk = new golgotha.maps.IconMarker({pal:a.pal, icon:a.icon}, a.ll);
		else if (a.color)
			mrk = new golgotha.maps.Marker({color:a.color}, a.ll);

		mrk.isExternal = a.hasOwnProperty('external_id');
		mrk.flight_id = mrk.isExternal ? a.external_id : a.flight_id;
		mrk.isBusy = a.busy;
		if (a.tabs.length != 0) {
			mrk.updateTab = golgotha.maps.util.updateTab;
			mrk.tabs = a.tabs;
		} else
			mrk.infoLabel = a.info;

		// Add the user ID
		if ((a.pilot) && (cbo != null)) {
			let lbl = a.pilot.name;
			if (a.pilot.code != null)
				lbl = lbl + ' (' + a.pilot.code + ')';

			let o = new Option(lbl, a.pilot.code);
			o.mrk = mrk;
			cbo.add(o, null);
			if (selectedPilot == a.pilot.code)
				cbo.selectedIndex = (cbo.options.length - 1);
		}

		// Set the the click handler
		google.maps.event.addListener(mrk, 'click', golgotha.maps.acars.clickAircraft);
		golgotha.maps.acars.acPositions.push(mrk);
		mrk.setMap(map);
	});

	if (js.dispatch.length > 0) golgotha.event.beacon('ACARS', 'Dispatch Positions');
	const allDSP = js.dispatch.sort(golgotha.maps.acars.sort);
	allDSP.forEach(function(d) { 
		var mrk;
		if (d.pal)
			mrk = new golgotha.maps.IconMarker({pal:d.pal, icon:d.icon}, d.ll);
		else if (d.color)
			mrk = new golgotha.maps.Marker({color:d.color}, d.ll);

		mrk.range = d.range;
		mrk.isBusy = d.busy;
		if (d.tabs.length != 0) {
			mrk.updateTab = golgotha.maps.util.updateTab;
			mrk.tabs = d.tabs;
		} else
			mrk.infoLabel = d.info;

		// Add the user ID
		if ((d.pilot) && (cbo != null)) {
			let o = new Option(d.pilot.name + ' (' + d.pilot.code + '/Dispatcher)', d.pilot.code);
			o.mrk = mrk;
			cbo.add(o, null);
			if (selectedPilot == d.pilot.code)
				cbo.selectedIndex = (cbo.options.length - 1);
		}

		// Set the the click handler
		google.maps.event.addListener(mrk, 'click', golgotha.maps.acars.clickDispatch);
		golgotha.maps.acars.dcPositions.push(mrk);
		mrk.setMap(map);
	});

	// Enable the Google Earth button depending on if we have any aircraft
	golgotha.util.disable('EarthButton', (js.aircraft.length == 0));

	// Display dispatch status
	const de = document.getElementById('dispatchStatus');
	if ((de) && (js.dispatch.length > 0)) {
		de.className = 'ter bld caps';
		de.innerHTML = 'Dispatcher Currently Online';
	} else if (de) {
		de.className = 'bld caps';	
		de.innerHTML = 'Dispatcher Currently Offline';
	}

	// Focus on the map
	golgotha.util.setHTML('isLoading', ' - ' + (js.aircraft.length + js.dispatch.length) + ' CONNECTIONS');
	if (cbo)
		golgotha.util.display('userSelect', (cbo.options.length > 1));

	return true;
};

return xmlreq;
};

golgotha.maps.acars.clickAircraft = function(e)
{
// Check what info we display
const f = document.forms[0];
const isProgress = f.showProgress.checked;
const isRoute = f.showRoute.checked;
const isInfo = f.showInfo.checked;
golgotha.event.beacon('ACARS', 'Flight Info');

// Display the info - show tab 0
if (isInfo && (this.tabs)) {
	this.updateTab(0);
	map.infoWindow.marker = this;
	map.infoWindow.open(map, this);
} else if (isInfo) {
	map.infoWindow.setContent(this.infoLabel);
	map.infoWindow.open(map, this); 
}

// Display flight progress / route
if (isProgress || isRoute) {
	map.removeMarkers(golgotha.maps.acars.routeData);
	map.removeMarkers(golgotha.maps.acars.tempData);
	map.removeMarkers(golgotha.maps.acars.routeWaypoints);
	golgotha.maps.acars.showFlightProgress(this, isProgress, isRoute);
}

document.pauseRefresh = true;
return true;
};

golgotha.maps.acars.clickDispatch = function(e)
{
// Check what info we display
const f = document.forms[0];
const isInfo = f.showInfo.checked;
golgotha.event.beacon('ACARS', 'Dispatch Info');

// Display the info
if (isInfo && (this.tabs)) {
	this.updateTab(0);
	map.infoWindow.marker = this;
	map.infoWindow.open(map, this);
} else if (isInfo) {
	map.infoWindow.marker = this;
	map.infoWindow.setContent(this.infoLabel);
	map.infoWindow.open(map, this);
}

// Display flight progress / route
if (!this.rangeCircle) {
	this.rangeCircle = golgotha.maps.acars.getServiceRange(this, this.range);
	if (this.rangeCircle) {
		golgotha.event.beacon('ACARS', 'Dispatch Service Range');
		this.rangeCircle.setMap(map);
	}
} else
	this.rangeCircle.setMap(map);

document.pauseRefresh = true;
return true;
};

golgotha.maps.acars.infoClose = function()
{
document.pauseRefresh = false;
if ((map.infoWindow.marker) && (map.infoWindow.marker.rangeCircle))
	map.infoWindow.marker.rangeCircle.setMap(null);

map.removeMarkers(golgotha.maps.acars.routeData);
map.removeMarkers(golgotha.maps.acars.tempData);
map.removeMarkers(golgotha.maps.acars.routeWaypoints);
map.removeMarkers(golgotha.maps.acars.routeMarkers);
map.closeWindow();
return true;	
};

golgotha.maps.acars.showFlightProgress = function(marker, doProgress, doRoute)
{
const xreq = new XMLHttpRequest();
xreq.timeout = 3500;
xreq.open('GET', 'acars_progress_json.ws?id=' + marker.flight_id + '&time=' + golgotha.util.getTimestamp(3000) + '&route=' + doRoute + '&isExternal=' + marker.isExternal, true);
xreq.onreadystatechange = function() {
	if ((xreq.readyState != 4) || (xreq.status != 200)) return false;

	// Draw the flight route
	const js = JSON.parse(xreq.responseText);
	if (doRoute) {
		let waypoints = [];
		js.waypoints.forEach(function(wp) { 
			waypoints.push(wp.ll); var mrk;
			if (wp.pal)
				mrk = new golgotha.maps.IconMarker({map:map, pal:wp.pal, icon:wp.icon, opacity:0.5}, wp.ll);
			else if (a.color)
				mrk = new golgotha.maps.Marker({map:map, color:wp.color, opacity:0.5}, wp.ll);

			golgotha.maps.acars.routeMarkers.push(mrk)
		});

		golgotha.event.beacon('ACARS', 'Flight Route Info');
		golgotha.maps.acars.routeWaypoints = new google.maps.Polyline({map:map, path:waypoints, strokeColor:'#af8040', strokeWeight:2, strokeOpacity:0.7, geodesic:true, zIndex:golgotha.maps.z.POLYLINE});
	}

	// Draw the flight progress
	if (doProgress) {
		golgotha.event.beacon('ACARS', 'Flight Progress Info');
		golgotha.maps.acars.routeData = new google.maps.Polyline({map:map, path:js.savedPositions, strokeColor:'#4080af', strokeWeight:2, strokeOpacity:0.8, zIndex:(golgotha.maps.z.POLYLINE-1)});
		golgotha.maps.acars.tempData = new google.maps.Polyline({map:map, path:js.tempPositions, strokeColor:'#20a0bf', strokeWeight:2, strokeOpacity:0.625, zIndex:(golgotha.maps.z.POLYLINE-1)});
	}

	return true;
};

xreq.send(null);
return true;
};

golgotha.maps.acars.sort = function(e1, e2) { return e1.pilot.name.localeCompare(e2.pilot.name); };
golgotha.maps.acars.getServiceRange = function(marker, range) {
	const bC = marker.isBusy ? '#c02020' : '#20c060';
	const fC = marker.isBusy ? '#802020' : '#208040';
	const fOp = marker.isBusy ? 0.1 : 0.2;
	return new google.maps.Circle({center:marker.getPosition(), radius:golgotha.maps.miles2Meter(range), strokeColor:bC, strokeWeight:1, strokeOpacity:0.65, fillColor:fC, fillOpacity:fOp, zIndex:golgotha.maps.z.POLYGON});
};

golgotha.maps.acars.zoomTo = function(combo) {
	const opt = combo.options[combo.selectedIndex];
	if ((!opt) || (opt.mrk == null)) return false;

	// Check if we zoom or just pan
	const f = document.forms[0];
	if (f.zoomToPilot.checked) map.setZoom(9);
	map.panTo(opt.mrk.getPosition());
	google.maps.event.trigger(opt.mrk, 'click');
	return true;
};

golgotha.maps.clear = function() { localStorage.removeItem('golgotha.mapInfo'); return true; };
golgotha.maps.save = function(m) {
	const inf = {type:m.getMapTypeId(), zoom:m.getZoom(), ctr:map.getCenter()};
	localStorage.setItem('golgotha.mapInfo', JSON.stringify(inf));
	return true;
};

golgotha.maps.acars.reloadData = function(isAuto) {
	const isVisible = !document.visibilityState || (document.visibilityState == 'visible');
	const doRefresh = document.forms[0].autoRefresh.checked;

	// Generate XMLHTTPRequest if we're not already viewing a flight
	if (!document.pauseRefresh && isVisible) {
		const isLoading = document.getElementById('isLoading');
		isLoading.innerHTML = ' - LOADING...';
		const xmlreq = golgotha.maps.acars.generateXMLRequest();
		xmlreq.send(null);
	}

	// Set timer to reload the data
	if (doRefresh && isAuto)
		window.setTimeout(golgotha.maps.acars.reloadData, golgotha.local.refresh, true);

	return true;
};

golgotha.maps.acars.showLegend = function(box) {
	const rows = golgotha.util.getElementsByClass('mapLegend', 'tr');
	rows.forEach(function(r) { golgotha.util.display(r, box.checked); });
	return true;
};

golgotha.maps.acars.showEarth = function() {
	self.location = '/acars_map_earth.ws';
	return true;
};

golgotha.maps.acars.updateSettings = function() {
	golgotha.maps.save(map);
	return true;
};
